==> apache-storm-2.1.1-src.tar.gz: apache-storm-2.1.1/storm-server/src/main/java/org/apache/storm/daemon/supervisor/Killable.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The ASF licenses this file to you under the Apache License, Version
 * 2.0 (the "License"); you may not use this file except in compliance with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package org.apache.storm.daemon.supervisor;

import java.io.IOException;

public interface Killable {

    /**
     * Kill the processes in this container nicely.
     * kill -15 equivalent
     * @throws IOException on any error
     */
    public void kill() throws IOException;

    /**
     * Kill the processes in this container violently.
     * kill -9 equivalent
     * @throws IOException on any error
     */
    public void forceKill() throws IOException;

    /**
     * @return true if all of the processes are dead, else false
     * @throws IOException on any error
     */
    public boolean areAllProcessesDead() throws IOException;

    /**
     * Clean up the container. It is not coming back.
     * by default do the same thing as when restarting.
     * @throws IOException on any error
     */
    public void cleanUp() throws IOException;
}

==> apache-storm-2.6.2-src.tar.gz: apache-storm-2.6.2/storm-server/src/main/java/org/apache/storm/daemon/supervisor/Killable.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The ASF licenses this file to you under the Apache License, Version
 * 2.0 (the "License"); you may not use this file except in compliance with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package org.apache.storm.daemon.supervisor;

import java.io.IOException;

public interface Killable {

    /**
     * Kill the processes in this container nicely.
     * kill -15 equivalent
     * @throws IOException on any error
     */
    void kill() throws IOException;

    /**
     * Kill the processes in this container violently.
     * kill -9 equivalent
     * @throws IOException on any error
     */
    void forceKill() throws IOException;

    /**
     * Check whether all processes are dead.
     * @return true if all of the processes are dead, else false
     * @throws IOException on any error
     */
    boolean areAllProcessesDead() throws IOException;

    /**
     * Clean up the container. It is not coming back.
     * by default do the same thing as when restarting.
     * @throws IOException on any error
     */
    void cleanUp() throws IOException;
}
